@@ -1,12 +1,12 @@
 class CodesDict(object):
-	def __init__(self, idict={}):
-		super(CodesDict, self).__setattr__('_dict', idict)
+	def __init__(self, codes={}):
+		super(CodesDict, self).__setattr__('_codes', codes)
 
 	def __setattr__(self, name, value):
-		self._dict[name] = value
+		self._codes[name] = value
 
 	def __getattr__(self, name):
-		return self._dict[name]
+		return self._codes[name]
 
 _codes = {
 	'waiting': 1,
